FillStyleLayer class final

Inheritance

Constructors

FillStyleLayer({required String id, required String sourceId, Map<String, Object> layout = const {}, Map<String, Object> paint = const {}, double minZoom = 0, double maxZoom = 24, List<Object>? filter, String? sourceLayerId})
Default constructor for a FillStyleLayer instance.
const

Properties

filter List<Object>?
A expression specifying conditions on source features. Only features that match the filter are displayed. Zoom expressions in filters are only evaluated at integer zoom levels. The feature-state expression is not supported in filter expressions.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique layer name.
finalinherited
layout Map<String, Object>
Layout properties for the layer.
finalinherited
maxZoom double
The maximum zoom level for the layer. At zoom levels equal to or greater than the maxzoom, the layer will be hidden.
finalinherited
minZoom double
The minimum zoom level for the layer. At zoom levels less than the minzoom, the layer will be hidden.
finalinherited
paint Map<String, Object>
Default paint properties for this layer.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId String
Name of a source description to be used for this layer. Required for all layer types except background.
finalinherited
sourceLayerId String?
Layer to use from a vector tile source. Required for vector tile sources; prohibited for all other source types, including GeoJSON sources.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited