MapEventDoubleClick class final

Emitted when the user clicks twice in a short amount of time on the map.

Supported platforms: iOS

Inheritance

Constructors

MapEventDoubleClick({required Geographic point, required Offset screenPoint})
Create a new MapEventDoubleClick object.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
point Geographic
The Geographic of where the user clicked at.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenPoint Offset
The screen coordinates in logical pixels where the user interacted with the map.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited