MapEventMoveCamera class final

Emitted when the map camera changes.

Inheritance

Constructors

MapEventMoveCamera({required MapCamera camera})
Create a new MapEventMoveCamera object.
const

Properties

camera → MapCamera
The new MapCamera.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited