MapEventStartMoveCamera class final
Emitted when the map camera changes.
Constructors
- MapEventStartMoveCamera({required CameraChangeReason reason})
-
Create a new MapEventStartMoveCamera object.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → CameraChangeReason
-
The reason the camera is changed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited