PermissionManager class abstract interface

The Permission Manager provides functionality to check if location permissions are granted and can request permissions.

The PermissionManager cannot be used on web.

Constructors

PermissionManager()
factory

Properties

backgroundLocationPermissionGranted bool
Returns true if access to background location is granted.
no setter
hashCode int
The hash code for this object.
no setterinherited
locationPermissionsGranted bool
Returns true if either access to coarse location or to fine location is granted.
no setter
runtimePermissionsRequired bool
Check if the operating system requires to ask for location permissions at runtime.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestLocationPermissions({required String explanation}) Future<bool>
Request runtime location permissions.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isSupported bool
Whether the permission manager is supported on the current platform.
no setter