equals3D method
bool
equals3D(
- covariant Position other, {
- double toleranceHoriz = defaultEpsilon,
- double toleranceVert = defaultEpsilon,
override
True if this position equals with other by testing 3D coordinates only.
Returns false if this or other is not a 3D position.
Differences on 2D coordinate values (ie. x and y, or lon and lat) between
this and other must be within toleranceHoriz.
Differences on vertical coordinate values (ie. z or elev) between
this and other must be within toleranceVert.
Tolerance values must be positive (>= 0.0).
Implementation
@override
bool equals3D(
Position other, {
double toleranceHoriz = defaultEpsilon,
double toleranceVert = defaultEpsilon,
}) =>
Position.testEquals3D(
this,
other,
toleranceHoriz: toleranceHoriz,
toleranceVert: toleranceVert,
);