QueriedLayer class

Return used for MapController.queryLayers.

Annotations

Constructors

QueriedLayer({required String layerId, required String? sourceId, required String? sourceLayer})
Create a new QueriedLayer object.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
layerId String
The ID of the layer the feature was rendered in.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId String?
The ID of the vector source that provided the feature.
final
sourceLayer String?
The ID of the vector source layer that provided the feature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override