Basic topic

Visit the documentation to learn more.

Classes

LngLatBounds
LatLng bounds class.
MapCamera
The current camera position on the map.
MapController
The MapController can be used to control, update and manipulate a rendered MapLibreMap.
MapGestures
Configure gestures that are enabled on the map.
MapLibreMap
The MapLibreMap widget that can be inserted into the flutter widget tree.
MapOptions
The MapOptions class is used to set default values for the MapLibreMap widget.
PermissionManager
The Permission Manager provides functionality to check if location permissions are granted and can request permissions.
QueriedLayer
Return used for MapController.queryLayers.
RenderedFeature
Data class representing a vector feature that was rendered on the map.
StyleController
The StyleController can be used to manipulate the style of a MapLibreMap. It can be accessed via MapController.style.

Enums

BearingRenderMode
The mode how render the location on the map. Used in MapController.enableLocation.
BearingTrackMode
The mode how the bearing should get tracked on the map. Used in MapController.trackLocation.

Typedefs

MapCreatedCallback = void Function(MapController controller)
Callback that fires once the native MapLibre map has been created for a MapLibreMap widget. It provides the MapController to the user.
MapEventCallback = void Function(MapEvent event)
Callback that fires every time a MapEvent gets emitted by the map.
StyleLoadedCallback = void Function(StyleController style)
Callback that fires once the map style has successfully loaded. It provides the StyleController to the user.