Style topic

Visit the layers chapter in the documentation to learn more.

Classes

BackgroundStyleLayer
A simple background layer.
CircleStyleLayer
A layer that contains circles.
FillExtrusionStyleLayer
A layer that contains fill extrusions.
FillStyleLayer
A layer that contains polygons.
GeoJsonSource
A GeoJSON source. Data must be provided via a "data" property, whose value can be a URL or inline GeoJSON. When using in a browser, the GeoJSON data must be on the same domain as the map or served with CORS headers.
HeatmapStyleLayer
A layer that contains heatmaps.
HillshadeStyleLayer
A layer that contains hillshades.
ImageSource
An image source. The url value contains the image location. The coordinates array contains Positions for the image corners listed in clockwise order: top left, top right, bottom right, bottom left.
LineStyleLayer
A layer that contains lines.
RasterDemCustomEncoding
Decodes tiles using the redFactor, blueFactor, greenFactor, baseShift parameters.
RasterDemEncoding
The encoding used by this source. Mapbox Terrain RGB is used by default.
RasterDemMapboxEncoding
Mapbox Terrain RGB tiles. See https://www.mapbox.com/help/access-elevation-data/#mapbox-terrain-rgb for more info.
RasterDemSource
A raster DEM source. Only supports Mapbox Terrain RGB and Mapzen Terrarium tiles.
RasterDemTerrariumEncoding
Terrarium format PNG tiles. See https://aws.amazon.com/es/public-datasets/terrain/ for more info.
RasterSource
A raster tile source.
RasterStyleLayer
A layer that contains markers.
The base Source class that can't be used directly.
StyleLayer
The base Layer class that can't be used directly.
StyleLayerWithSource
A StyleLayer that pulls its data from a Source. Basically every layer except BackgroundStyleLayer.
SymbolStyleLayer
A layer that contains markers.
VectorSource
A vector tile source. Tiles must be in Mapbox Vector Tile format. All geometric coordinates in vector tiles must be between -1 * extent and (extent * 2) - 1 inclusive. All layers that use a vector source must specify a source-layer value.
VideoSource
A video source. The urls value is an array. For each URL in the array, a video element source will be created. To support the video across browsers, supply URLs in multiple formats.

Enums

TileScheme
Influences the y direction of the tile coordinates.

Typedefs

StyleLoadedCallback = void Function(StyleController style)
Callback that fires once the map style has successfully loaded. It provides the StyleController to the user.