Layer<G extends Feature<Geometry> > class
abstract
This class is the base for all annotation layer classes.
- Implementers
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
list
→ List<
G> -
The List of geometry features.
final
- maxZoom → double
-
The maximum zoom level that the Layer is displayed.
final
- minZoom → double
-
The minimum zoom level that the Layer is displayed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createStyleLayer(
int index) → StyleLayer - Add the annotation layer to the map.
-
getLayerId(
int index) → String - Get a unique layer id.
-
getLayout(
) → Map< String, Object> - Build the layout properties.
-
getPaint(
) → Map< String, Object> - Build the paint properties.
-
getSourceId(
int index) → String - Get a unique source id.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override