trackLocation abstract method
Future<void>
trackLocation({
- bool trackLocation = true,
- BearingTrackMode trackBearing = BearingTrackMode.gps,
Track the user location on the map
Set trackLocation to false if only the bearing should get tracked
(defaults to true).
Use trackBearing to set if the bearing should get tracked according to
the GPS location, compass direction or ignored.
Implementation
Future<void> trackLocation({
bool trackLocation = true,
BearingTrackMode trackBearing = BearingTrackMode.gps,
});