RenderedFeature class
Data class representing a vector feature that was rendered on the map.
- Annotations
Constructors
-
RenderedFeature({required Object? id, required Map<
String, Object?> properties}) -
Create a new RenderedFeature.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → Object?
-
If present, an object uniquely identifying the feature in the vector
source. May be either a string or an integer.
final
-
properties
→ Map<
String, Object?> -
The properties of the feature as provided by its source.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override