Events topic
Visit the Events chapter in the documentation to learn more.
Classes
- MapEvent
- Base class for all the events emitted by the MapLibreMap.
- MapEventCameraIdle
- Emitted when the map camera enters an idle state.
- MapEventClick
- Emitted when the user clicks on the map.
- MapEventDoubleClick
- Emitted when the user clicks twice in a short amount of time on the map.
- MapEventIdle
- Emitted when the map enters an idle state.
- MapEventLongClick
- Emitted when the user clicks on the map and holds button down at the same location for some time.
- MapEventMapCreated
- Emitted when the native map view has been created.
- MapEventMoveCamera
- Emitted when the map camera changes.
- MapEventSecondaryClick
- Emitted when the user clicks with the secondary button on the map. This would be classically the right mouse button.
- MapEventStartMoveCamera
- Emitted when the map camera changes.
- MapEventStyleLoaded
- Emitted when the map style has been loaded.
- MapEventUserInput
- Emitted when the user interacts with the map in any way. Use this class if you don't care about the type of gesture.
Enums
- CameraChangeReason
- The reason the camera is changing.
Typedefs
- MapEventCallback = void Function(MapEvent event)
- Callback that fires every time a MapEvent gets emitted by the map.