Offline topic

Visit the Offline chapter in the documentation to learn more.

Classes

OfflineManager
Use the offline manager to download map regions for offline usage.
OfflineRegion
Model class that represents a map region for offline usage.